@@ -1,10 +1,12 @@
 import traceback
 import socket
 import warnings
+import datetime
 
 from django.conf import settings
 from django.http import Http404
 from django.utils.hashcompat import md5_constructor
+from django.utils.encoding import smart_unicode
 
 from djangodblog.models import Error, ErrorBatch
 
@@ -23,7 +25,7 @@ class DBLogMiddleware(object):
 
         defaults = dict(
             class_name  = class_name,
-            message     = getattr(exception, 'message', ''),
+            message     = smart_unicode(exception),
             url         = request.build_absolute_uri(),
             server_name = server_name,
             traceback   = tb_text,
@@ -40,6 +42,7 @@ class DBLogMiddleware(object):
             if not created:
                 batch.times_seen += 1
                 batch.resolved = False
+                batch.last_seen = datetime.datetime.now()
                 batch.save()
         except Exception, exc:
-            warnings.warn(unicode(exc))
\ No newline at end of file
+            warnings.warn(smart_unicode(exc))
\ No newline at end of file
